---
name: "🚀 Feature request"
about: "Suggest an idea for this project 💡"
title: ''
labels: enhancement
assignees:
---

## :rocket: Feature Request

<!-- A clear and concise description of the feature proposal. -->

## :speech_balloon: Motivation

<!-- Please describe the motivation for this proposal. -->

## :artificial_satellite: Alternatives

<!-- A clear and concise description of any alternative solutions or features you have considered. -->

## :paperclip: Additional Context

<!-- Add any other context or screenshots about the feature request here. -->
